#!/usr/bin/perl
#
# mksampledata.pl 
#
# (c) 2013 Bojan Ramsak, <info@epg.cherryhill.eu>
#
# Generate a sample data file containing sample events for importing into 
# the EPG database.
#
# Additional information on http://epg.cherryhill.eu
## -----------------------------------------------------------------------------
use strict;
use POSIX qw(strftime);

open( my $io, ">sample.csv") or die( "Error opening sample.csv: $!");

my $lastMidnight = int( time()/(24*60*60))*24*60*60;

# read the sample program schedule
while( <DATA>) {
    my( @fields) = split( /,/, $_);

    # correct the time for today (!!! time must be always in GMT)
    $fields[1] = '"'.strftime("%d.%m.%Y %H:%M:%S", localtime( $fields[1]+$lastMidnight)).'"';

    print( $io join( ",", @fields));
}
close( $io);

print( "Sample data written to file.\n");

exit( 0);

__END__
"bbc1",6000,300,"Weatherview","Detailed weather forecast."
"bbc1",6300,3600,"The Dark: Nature's Nighttime World","1/3. Central American Jungle: Nature series. A team of biologists and specialist camera crew explore the jungles of Costa Rica to find out how animals have adapted to life in the dark. [AD,S,SL]"
"bbc1",9900,3600,"Holby City","Michael must take desperate action with a patient's care. Tara, desperate to prove she can cope on her own, endangers a patient's life rather than ask for help. [AD,S,SL]"
"bbc1",13500,3600,"Amish: A Secret Life","An intimate portrait of Amish family life and faith, following Old Order Amish couple Miriam and David and their family, capturing the reason why they decided to open their lives. [AD,S,SL]"
"bbc1",17100,4500,"BBC News","BBC One joins the BBC's rolling news channel for a night of news, with bulletins on the hour and the headlines every 15 minutes."
"bbc1",21600,5400,"Breakfast","The latest news, sport, business and weather from the BBC's Breakfast team. Also in HD."
"bbc1",27000,5400,"Match of the Day","Highlights of yesterday's Premier League matches, including Aston Villa v Everton, Chelsea v Newcastle, Manchester United v Fulham, Southampton v Wigan and Tottenham v West Brom. Also in HD."
"bbc1",32400,3600,"BBC News","The latest national and international news from the BBC. Also in HD."
"bbc1",36000,3600,"Sunday Morning Live","9/18. Topical debate. Samira Ahmed is joined by actor Bill Roache, Francis Beckett, Carole Malone and Rosie Freeman-Jones to discuss press regulation, forgiveness and infidelity. Also in HD."
"bbc1",39600,3600,"Country Tracks","Joe Crowley travels the Caledonian Canal from Aonach Mor Mountain to the North Sea, where he goes dolphin spotting. [S] Followed by Weather for the Week Ahead."
"bbc1",43200,300,"BBC News","The latest national and international news from the BBC."
"bbc1",43500,3600,"Homes Under the Hammer","Property auction series. Martin Roberts and Lucy Alexander visit a cottage in Exeter, a house in Kent and some stunning accommodation in Glasgow."
"bbc1",47100,3600,"Bargain Hunt","Antiques challenge. Four intrepid teams take part in a one-hour bumper Bargain Hunt special. Experts Kate Bliss and David Harper guide the teams towards the best buys."
"bbc1",50700,2400,"Cash in the Attic","Series looking at the value of household junk. Josephine Kay wants to raise  1,000 so that she can experience the healing properties of the Dead Sea."
"bbc1",53100,3600,"Escape to the Country","Jules Hudson visits Dorset to help a homesick couple swap their French chateau for a 1.6 million pound house in the English countryside with five en-suite bedrooms."
"bbc1",56700,3600,"Ocean Giants","2/3. Deep Thinkers: Documentary focusing on the intelligence of whales and dolphins, as Professor Denise Herzing attempts to find out how close their minds are to those of humans. Also in HD. [AD,S]"
"bbc1",60300,2100,"Songs of Praise","Eamonn Holmes meets people who have a passion for faith and sport. Music from Keith and Kristyn Getty, Rend Collective and hymns from St Killian's College Chapel. Also in HD."
"bbc1",62400,2700,"The Indian Doctor","2/5. Prem finds himself under pressure to track down and save Dan before it is too late. Also in HD. [AD,S]"
"bbc1",65100,900,"BBC News","The latest national and international news stories from the BBC News team."
"bbc1",66000,600,"Midlands Today","The latest news, sport and weather for the Midlands. [S] Followed by national weather."
"bbc1",66600,3600,"Britain's Hidden Heritage","2/3. Mount Stewart: Paul Martin travels to Northern Ireland and to Mount Stewart, a country house recently bequeathed to the nation. Clare Balding visits Lichfield Cathedral."
"bbc1",70200,3600,"Countryfile","In a livestock special, Adam looks back at some of the team's favourite encounters with farm animals. Also in HD. [S] Followed by Weather for the Week Ahead."
"bbc1",73800,5400,"Inspector George Gently","New series. Gently Northern Soul: Gently and Bacchus awaken to the consequences of racism when a young girl is murdered. Also in HD. [AD,S]"
"bbc1",79200,900,"BBC News","The latest national and international news, with reports from BBC correspondents worldwide."
"bbc1",80100,600,"Midlands Today","The latest news, sport and weather for the Midlands. [S] Followed by national weather."
"bbc1",80700,3600,"Match of the Day 2","Colin Murray presents highlights of the day's two Premier League games. Champions Manchester City faced Liverpool at Anfield, while Stoke took on Arsenal at the Britannia Stadium. Also in HD."
"bbc1",84300,1800,"In With the Flynns","2/6. Liam Flynn, Party Legend: Comedy. The Flynns hold an anniversary party for Caroline's parents, Pat and Alan. Liam's patience and party skills are tested when Pat upsets Chloe. Also in HD."
"bbc1",86100,6300,"Flashbacks of a Fool","A Hollywood star returns home to attend the funeral of a childhood friend, a tragedy which awakens memories of his own youth. Starring Daniel Craig. Contains very strong language." 
"bbc1",92100,300,"Weatherview","Detailed weather forecast."
"bbc1",92400,3600,"The Dark: Nature's Nighttime World","1/3. Central American Jungle: Nature series. A team of biologists and specialist camera crew explore the jungles of Costa Rica to find out how animals have adapted to life in the dark. [AD,S,SL]"
"bbc1",96000,3600,"Holby City","Michael must take desperate action with a patient's care. Tara, desperate to prove she can cope on her own, endangers a patient's life rather than ask for help. [AD,S,SL]"
"bbc1",99600,3600,"Amish: A Secret Life","An intimate portrait of Amish family life and faith, following Old Order Amish couple Miriam and David and their family, capturing the reason why they decided to open their lives. [AD,S,SL]"
"bbc1",103200,4500,"BBC News","BBC One joins the BBC's rolling news channel for a night of news, with bulletins on the hour and the headlines every 15 minutes."
"bbc1",107700,5400,"Breakfast","The latest news, sport, business and weather from the BBC's Breakfast team. Also in HD."
"bbc1",113100,5400,"Match of the Day","Highlights of yesterday's Premier League matches, including Aston Villa v Everton, Chelsea v Newcastle, Manchester United v Fulham, Southampton v Wigan and Tottenham v West Brom. Also in HD."
"bbc1",118500,3600,"BBC News","The latest national and international news from the BBC. Also in HD."
"bbc1",122100,3600,"Sunday Morning Live","9/18. Topical debate. Samira Ahmed is joined by actor Bill Roache, Francis Beckett, Carole Malone and Rosie Freeman-Jones to discuss press regulation, forgiveness and infidelity. Also in HD."
"bbc1",125700,3600,"Country Tracks","Joe Crowley travels the Caledonian Canal from Aonach Mor Mountain to the North Sea, where he goes dolphin spotting. [S] Followed by Weather for the Week Ahead."
"bbc1",129300,300,"BBC News","The latest national and international news from the BBC."
"bbc1",129600,3600,"Homes Under the Hammer","Property auction series. Martin Roberts and Lucy Alexander visit a cottage in Exeter, a house in Kent and some stunning accommodation in Glasgow."
"bbc1",133200,3600,"Bargain Hunt","Antiques challenge. Four intrepid teams take part in a one-hour bumper Bargain Hunt special. Experts Kate Bliss and David Harper guide the teams towards the best buys."
"bbc1",136800,2400,"Cash in the Attic","Series looking at the value of household junk. Josephine Kay wants to raise  1,000 so that she can experience the healing properties of the Dead Sea."
"bbc1",139200,3600,"Escape to the Country","Jules Hudson visits Dorset to help a homesick couple swap their French chateau for a 1.6 million pound house in the English countryside with five en-suite bedrooms."
"bbc1",142800,3600,"Ocean Giants","2/3. Deep Thinkers: Documentary focusing on the intelligence of whales and dolphins, as Professor Denise Herzing attempts to find out how close their minds are to those of humans. Also in HD. [AD,S]"
"bbc1",146400,2100,"Songs of Praise","Eamonn Holmes meets people who have a passion for faith and sport. Music from Keith and Kristyn Getty, Rend Collective and hymns from St Killian's College Chapel. Also in HD."
"bbc1",148500,2700,"The Indian Doctor","2/5. Prem finds himself under pressure to track down and save Dan before it is too late. Also in HD. [AD,S]"
"bbc1",151200,900,"BBC News","The latest national and international news stories from the BBC News team."
"bbc1",152100,600,"Midlands Today","The latest news, sport and weather for the Midlands. [S] Followed by national weather."
"bbc1",152700,3600,"Britain's Hidden Heritage","2/3. Mount Stewart: Paul Martin travels to Northern Ireland and to Mount Stewart, a country house recently bequeathed to the nation. Clare Balding visits Lichfield Cathedral."
"bbc1",156300,3600,"Countryfile","In a livestock special, Adam looks back at some of the team's favourite encounters with farm animals. Also in HD. [S] Followed by Weather for the Week Ahead."
"bbc1",159900,5400,"Inspector George Gently","New series. Gently Northern Soul: Gently and Bacchus awaken to the consequences of racism when a young girl is murdered. Also in HD. [AD,S]"
"bbc1",165300,900,"BBC News","The latest national and international news, with reports from BBC correspondents worldwide."
"bbc1",166200,600,"Midlands Today","The latest news, sport and weather for the Midlands. [S] Followed by national weather."
"bbc1",166800,3600,"Match of the Day 2","Colin Murray presents highlights of the day's two Premier League games. Champions Manchester City faced Liverpool at Anfield, while Stoke took on Arsenal at the Britannia Stadium. Also in HD."
"bbc1",170400,1800,"In With the Flynns","2/6. Liam Flynn, Party Legend: Comedy. The Flynns hold an anniversary party for Caroline's parents, Pat and Alan. Liam's patience and party skills are tested when Pat upsets Chloe. Also in HD."
"bbc1",172200,6300,"Flashbacks of a Fool","A Hollywood star returns home to attend the funeral of a childhood friend, a tragedy which awakens memories of his own youth. Starring Daniel Craig. Contains very strong language." 
