#!/usr/bin/perl
#
# ringelspiel.pl
#
# (c) 2013 Bojan Ramsak, <info@epg.cherryhill.eu>
#
# Simple DVB data carousel for playing EPG data. Part of the cherryEPG tool suite.
#
# cherryEPG is free software; you can redistribute it and/or modify it under 
# the terms of the Artistic License v2.0.
#
# Additional information on http://epg.cherryhill.eu
## -----------------------------------------------------------------------------
use strict;
use warnings;
use Socket;
use DVB::Carousel;
use POSIX qw(ceil);
use Time::HiRes qw(usleep);

# Here you can change the streaming destination multicast address and port 
my $host = "239.1.1.50";
my $port = 5500;

# source data
my $carouselDb = "carousel.sqlite";

print "ringelspiel - Copyright 2013 Bojan Ramsak\n";

my $myCarousel = DVB::Carousel->new( $carouselDb) || die( "Error opening carousel database [$carouselDb]: $!");

# open socket for streaming
socket( my $target, PF_INET, SOCK_DGRAM, getprotobyname('udp')) or die( "Error opening udp socket: $!");

# and define ip/port addr
my $ipaddr = inet_aton( $host);
my $portaddr = sockaddr_in( $port, $ipaddr);

# the continuity counter
my $continuityCounter = 0;

while( 1) {

    # get all data fot the EIT
    my $meta = $myCarousel->getMts( 18);

    if( ! defined $meta) {
        print "No MTS chunk found for playing\n";
        sleep( 1);
        next;
    }

    # set the variables
    my $interval = $$meta[1];
    my $mts = $$meta[2];
    my $mtsCount = length( $mts) / 188;
    my $packetCounter = 0;
    
    # correct continuity counter    
    for ( my $j = 3 ; $j < length( $mts) ; $j += 188 ) {
        substr( $mts, $j, 1, chr( 0b00010000 | ( $continuityCounter & 0x0f ) ) );
        $continuityCounter += 1;
    }

    # add stuffing packets to have a multiple of 7 packets in the buffer
    # Why 7 packets? 
    # 7 x 188 = 1316
    # Because 7 TS packets fit in a typical UDP packet.
    my $i = $mtsCount % 7;
    while ( $i > 0 && $i < 7) {
        $mts .= "\x47\x1f\xff\x10"."\xff" x 184;    # stuffing packet
        $i += 1;
    }
    
    # correct the count of packets
    $mtsCount = length( $mts) / 188;

    # calculate the waiting time between playing chunks of 7 packets in micro seconds
    my $gap = ceil( $interval / $mtsCount * 7 * 1000);
    
    # play packets of 7 x 188bytes
    while ($packetCounter < $mtsCount) {
        my $chunkCount = $mtsCount-$packetCounter;
        $chunkCount = 7 if $chunkCount > 7; 
        
        send( $target, substr( $mts, $packetCounter * 188, $chunkCount * 188), 0, $portaddr);
        $packetCounter += $chunkCount;
        usleep( $gap);
    }
}
